@@ -121,6 +121,13 @@ def run_twisted_server(app):
 
     return action
 
+def show_urls(app):
+    def action():
+        """Displays all of the url matching routes for the project."""
+        for rule in app.url_map.iter_rules():
+            print "%-30s"%rule, rule.endpoint
+    return action
+
 
 def bshell(app):
     def action():
@@ -188,6 +195,7 @@ class Manager(object):
                 'clean'       : clean(application),
                 'generate_secret_key':generate_secret_key(application),
                 'runtwisted'  :   run_twisted_server(application),
+                'show_urls'   :   show_urls(application),
 
         }
 
